pub struct Client<RT: HttpClientInterface> { /* private fields */ }Expand description
A telemetric client for reporting measurements to a server
Implementations
Sourceimpl<RT: HttpClientInterface> Client<RT>
impl<RT: HttpClientInterface> Client<RT>
Sourcepub fn new(
runtime: RT,
uri: impl Into<String>,
software_id: impl Into<String>,
app_info: (impl Into<String>, impl Into<String>, impl Into<String>),
) -> Self
pub fn new( runtime: RT, uri: impl Into<String>, software_id: impl Into<String>, app_info: (impl Into<String>, impl Into<String>, impl Into<String>), ) -> Self
Create a new telemetric client app_info takes the form (qualifier, organization, application) and is used to locate where to store the telemetric data
Sourcepub fn enable_reporting(&self)
pub fn enable_reporting(&self)
Enable reporting of telemetric data
Sourcepub fn disable_reporting(&self)
pub fn disable_reporting(&self)
Disable reporting of telemetric data